pub struct Block { /* private fields */ }Expand description
Contains one or more channels of 4 ms of audio data.
The audio is split into one or more frequency bands, each with a sampling
rate of 16 kHz. Each band/channel combination holds BLOCK_SIZE (64)
samples.
Implementations
Sourceimpl Block
impl Block
pub fn new(num_bands: usize, num_channels: usize) -> Self
pub fn new_with_value(num_bands: usize, num_channels: usize, value: f32) -> Self
pub fn num_bands(&self) -> usize
pub fn num_channels(&self) -> usize
Sourcepub fn set_num_channels(&mut self, num_channels: usize)
pub fn set_num_channels(&mut self, num_channels: usize)
Modifies the number of channels and zeros all samples.
Sourcepub fn view(&self, band: usize, channel: usize) -> &[f32]
pub fn view(&self, band: usize, channel: usize) -> &[f32]
Returns a slice of BLOCK_SIZE samples for the given band and channel.