BlockProcessor

Struct BlockProcessor 

pub struct BlockProcessor { /* private fields */ }
Block-level echo cancellation processor.

Implementations

Source

impl BlockProcessor

pub fn new( config: &EchoCanceller3Config, sample_rate_hz: usize, num_render_channels: usize, num_capture_channels: usize, ) -> Self

pub fn with_backend( backend: SimdBackend, config: &EchoCanceller3Config, sample_rate_hz: usize, num_render_channels: usize, num_capture_channels: usize, ) -> Self

Creates a new block processor with an explicit SIMD backend.

pub fn get_metrics(&self) -> BlockProcessorMetricsOutput

Returns current echo cancellation metrics.

pub fn set_audio_buffer_delay(&mut self, delay_ms: i32)

Provides an optional external estimate of the audio buffer delay.

pub fn process_capture( &mut self, echo_path_gain_change: bool, capture_signal_saturation: bool, linear_output: Option<&mut Block>, capture_block: &mut Block, )

Processes a block of capture data.

pub fn buffer_render(&mut self, block: &Block)

Buffers a block of render data.

pub fn update_echo_leakage_status(&mut self, leakage_detected: bool)

Reports whether echo leakage has been detected.

pub fn set_capture_output_usage(&mut self, capture_output_used: bool)

Specifies whether the capture output will be used.