pub struct RenderLevels {
pub active_render_limit: f32,
pub poor_excitation_render_limit: f32,
pub poor_excitation_render_limit_ds8: f32,
pub render_power_gain_db: f32,
}Expand description
Render signal level thresholds.
Fields
active_render_limit: f32Power threshold above which the render signal is considered active (default: 100.0).
poor_excitation_render_limit: f32Power threshold below which render excitation is considered poor (default: 150.0).
poor_excitation_render_limit_ds8: f32Poor excitation threshold for 8x down-sampled signals (default: 20.0).
render_power_gain_db: f32Gain in dB applied to the render power estimate (default: 0.0).